<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>SelectLayoutDialog</name>
    <message>
        <location filename="selectlayoutdialog.ui" line="14"/>
        <source>Select Keyboard Layout and Variant</source>
        <translation>キーボード・レイアウトとバリエーションを選択</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="29"/>
        <source>Layout</source>
        <translation>レイアウト</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="47"/>
        <source>Variants</source>
        <translation>バリエーション</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.cpp" line="57"/>
        <source>No Variant</source>
        <translation>バリエーション無し</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="window.ui" line="14"/>
        <location filename="window.cpp" line="113"/>
        <location filename="window.cpp" line="117"/>
        <source>System Keyboard</source>
        <translation>システムキーボード</translation>
    </message>
    <message>
        <location filename="window.ui" line="28"/>
        <source>Layouts</source>
        <translation>レイアウト</translation>
    </message>
    <message>
        <location filename="window.ui" line="34"/>
        <source>Keyboard Model</source>
        <translation>キーボードモデル</translation>
    </message>
    <message>
        <location filename="window.ui" line="55"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="window.ui" line="68"/>
        <source>Keyboard Layouts</source>
        <translation>キーボード・レイアウト</translation>
    </message>
    <message>
        <location filename="window.ui" line="158"/>
        <source>Hotkeys</source>
        <translation>ホットキー</translation>
    </message>
    <message>
        <location filename="window.ui" line="181"/>
        <source>Advanced</source>
        <translation>上級者向け</translation>
    </message>
    <message>
        <location filename="window.ui" line="209"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Failed to open file: </source>
        <translation>開くことが出来なかったファイル: </translation>
    </message>
    <message>
        <location filename="window.cpp" line="241"/>
        <source>Most settings will not be loaded</source>
        <translation>ほとんどの設定はロードされません
</translation>
    </message>
    <message>
        <location filename="window.cpp" line="352"/>
        <source>Disabled</source>
        <translation>無効化</translation>
    </message>
</context>
</TS>